| Copyright | (c) 2013-2023 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | Safe-Inferred |
| Language | Haskell2010 |
Amazonka.PinpointEmail.Types.BlacklistEntry
Description
Synopsis
- data BlacklistEntry = BlacklistEntry' {
- description :: Maybe Text
- listingTime :: Maybe POSIX
- rblName :: Maybe Text
- newBlacklistEntry :: BlacklistEntry
- blacklistEntry_description :: Lens' BlacklistEntry (Maybe Text)
- blacklistEntry_listingTime :: Lens' BlacklistEntry (Maybe UTCTime)
- blacklistEntry_rblName :: Lens' BlacklistEntry (Maybe Text)
Documentation
data BlacklistEntry Source #
An object that contains information about a blacklisting event that impacts one of the dedicated IP addresses that is associated with your account.
See: newBlacklistEntry smart constructor.
Constructors
| BlacklistEntry' | |
Fields
| |
Instances
newBlacklistEntry :: BlacklistEntry Source #
Create a value of BlacklistEntry with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
$sel:description:BlacklistEntry', blacklistEntry_description - Additional information about the blacklisting event, as provided by the
blacklist maintainer.
$sel:listingTime:BlacklistEntry', blacklistEntry_listingTime - The time when the blacklisting event occurred, shown in Unix time
format.
$sel:rblName:BlacklistEntry', blacklistEntry_rblName - The name of the blacklist that the IP address appears on.
blacklistEntry_description :: Lens' BlacklistEntry (Maybe Text) Source #
Additional information about the blacklisting event, as provided by the blacklist maintainer.
blacklistEntry_listingTime :: Lens' BlacklistEntry (Maybe UTCTime) Source #
The time when the blacklisting event occurred, shown in Unix time format.
blacklistEntry_rblName :: Lens' BlacklistEntry (Maybe Text) Source #
The name of the blacklist that the IP address appears on.