| Copyright | (c) 2013-2023 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | Safe-Inferred |
| Language | Haskell2010 |
Amazonka.PinpointEmail.Types.MessageTag
Description
Synopsis
- data MessageTag = MessageTag' {}
- newMessageTag :: Text -> Text -> MessageTag
- messageTag_name :: Lens' MessageTag Text
- messageTag_value :: Lens' MessageTag Text
Documentation
data MessageTag Source #
Contains the name and value of a tag that you apply to an email. You can use message tags when you publish email sending events.
See: newMessageTag smart constructor.
Constructors
| MessageTag' | |
Fields
| |
Instances
Arguments
| :: Text | |
| -> Text | |
| -> MessageTag |
Create a value of MessageTag with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
$sel:name:MessageTag', messageTag_name - The name of the message tag. The message tag name has to meet the
following criteria:
- It can only contain ASCII letters (a–z, A–Z), numbers (0–9), underscores (_), or dashes (-).
- It can contain no more than 256 characters.
$sel:value:MessageTag', messageTag_value - The value of the message tag. The message tag value has to meet the
following criteria:
- It can only contain ASCII letters (a–z, A–Z), numbers (0–9), underscores (_), or dashes (-).
- It can contain no more than 256 characters.
messageTag_name :: Lens' MessageTag Text Source #
The name of the message tag. The message tag name has to meet the following criteria:
- It can only contain ASCII letters (a–z, A–Z), numbers (0–9), underscores (_), or dashes (-).
- It can contain no more than 256 characters.
messageTag_value :: Lens' MessageTag Text Source #
The value of the message tag. The message tag value has to meet the following criteria:
- It can only contain ASCII letters (a–z, A–Z), numbers (0–9), underscores (_), or dashes (-).
- It can contain no more than 256 characters.